==> haskell-microstache-1.0.1.1-171-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microstache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microstache
version:              1.0.1.1
visibility:           public
id:                   microstache-1.0.1.1-FHeHJZVQvYt6PXdrTcIotY
key:                  microstache-1.0.1.1-FHeHJZVQvYt6PXdrTcIotY
license:              BSD-3-Clause
maintainer:           Oleg Grenrus<oleg.grenrus@iki.fi>
author:
    Mark Karpov <markkarpov@openmailbox.org>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/phadej/microstache
synopsis:             Mustache templates for Haskell
description:
    Mustache templates for Haskell.

    Based on @stache@ library, which uses @megaparsec@.
    This library uses @parsec@, thus the name: @microstache@.

category:             Text
abi:                  3f8f3b43b739d9346e9bdd28bb01fb7c
exposed:              True
exposed-modules:
    Text.Microstache Text.Microstache.Compile Text.Microstache.Parser
    Text.Microstache.Render Text.Microstache.Type

import-dirs:          /usr/lib/ghc-8.10.1/site-local/microstache-1.0.1.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/microstache-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/microstache-1.0.1.1
hs-libraries:         HSmicrostache-1.0.1.1-FHeHJZVQvYt6PXdrTcIotY
depends:
    aeson-1.5.3.0-otLRtC5gX1JmoTwFxL1re base-4.14.0.0
    bytestring-0.10.10.0 containers-0.6.2.1 deepseq-1.4.4.0
    directory-1.3.6.0 filepath-1.4.2.1 parsec-3.1.14.0 text-1.2.3.2
    transformers-0.5.6.2
    unordered-containers-0.2.12.0-8JXKszpgMXuybqLOiZpMH
    vector-0.12.1.2-KotqULZza37AeFlfLxbJau

haddock-interfaces:   /usr/share/doc/haskell-microstache/html/microstache.haddock
haddock-html:         /usr/share/doc/haskell-microstache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microstache-1.0.1.1-184-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microstache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microstache
version:              1.0.1.1
visibility:           public
id:                   microstache-1.0.1.1-HQr6DHZWYUy1Zl5AaDUH8L
key:                  microstache-1.0.1.1-HQr6DHZWYUy1Zl5AaDUH8L
license:              BSD-3-Clause
maintainer:           Oleg Grenrus<oleg.grenrus@iki.fi>
author:
    Mark Karpov <markkarpov@openmailbox.org>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/phadej/microstache
synopsis:             Mustache templates for Haskell
description:
    Mustache templates for Haskell.

    Based on @stache@ library, which uses @megaparsec@.
    This library uses @parsec@, thus the name: @microstache@.

category:             Text
abi:                  acaabd7ba98279372dd04f255881abe7
exposed:              True
exposed-modules:
    Text.Microstache Text.Microstache.Compile Text.Microstache.Parser
    Text.Microstache.Render Text.Microstache.Type

import-dirs:          /usr/lib/ghc-8.10.2/site-local/microstache-1.0.1.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/microstache-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/microstache-1.0.1.1
hs-libraries:         HSmicrostache-1.0.1.1-HQr6DHZWYUy1Zl5AaDUH8L
depends:
    aeson-1.5.4.0-5vxqgGZiwHzJS2LSOWy84c base-4.14.1.0
    bytestring-0.10.10.0 containers-0.6.2.1 deepseq-1.4.4.0
    directory-1.3.6.0 filepath-1.4.2.1 parsec-3.1.14.0 text-1.2.3.2
    transformers-0.5.6.2
    unordered-containers-0.2.12.0-5Ef7XCamkg9H83KRAEej2p
    vector-0.12.1.2-KHX5U3TBRrFFuOQ5e4wn9L

haddock-interfaces:   /usr/share/doc/haskell-microstache/html/microstache.haddock
haddock-html:         /usr/share/doc/haskell-microstache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
